==> nomachine-7.10.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/NXTools.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXTools::BEGIN{package NXTools;no warnings;require Common::NXPaths;do{
"\x43\x6f\x6d\x6d\x6f\x6e\x3a\x3a\x4e\x58\x50\x61\x74\x68\x73"->import};}sub 
NXTools::getWindowsSystemPath{package NXTools;no warnings;(my $systemPath=(""));
if ((defined ($ENV{
"\x53\x79\x73\x74\x65\x6d\x44\x69\x72\x65\x63\x74\x6f\x72\x79"})and (length (
$ENV{"\x53\x79\x73\x74\x65\x6d\x44\x69\x72\x65\x63\x74\x6f\x72\x79"})>
(0x0224+ 6601-0x1bed)))){($systemPath=$ENV{
"\x53\x79\x73\x74\x65\x6d\x44\x69\x72\x65\x63\x74\x6f\x72\x79"});}elsif ((
defined ($ENV{"\x57\x69\x6e\x44\x69\x72"})and (length ($ENV{
"\x57\x69\x6e\x44\x69\x72"})>(0x1672+ 675-0x1915)))){($systemPath=(($ENV{
"\x57\x69\x6e\x44\x69\x72"}.$GLOBAL::DIRECTORY_SLASH).
"\x53\x79\x73\x74\x65\x6d\x33\x32"));}elsif ((defined ($ENV{
"\x53\x79\x73\x74\x65\x6d\x52\x6f\x6f\x74"})and (length ($ENV{
"\x53\x79\x73\x74\x65\x6d\x52\x6f\x6f\x74"})>(0x05ad+ 4105-0x15b6)))){(
$systemPath=(($ENV{"\x53\x79\x73\x74\x65\x6d\x52\x6f\x6f\x74"}.
$GLOBAL::DIRECTORY_SLASH)."\x53\x79\x73\x74\x65\x6d\x33\x32"));}elsif ((defined 
($ENV{"\x53\x79\x73\x74\x65\x6d\x44\x72\x69\x76\x65"})and (length ($ENV{
"\x53\x79\x73\x74\x65\x6d\x44\x72\x69\x76\x65"})>(0x034b+ 4174-0x1399)))){(
$systemPath=(((($ENV{"\x53\x79\x73\x74\x65\x6d\x44\x72\x69\x76\x65"}.
$GLOBAL::DIRECTORY_SLASH)."\x57\x69\x6e\x64\x6f\x77\x73").
$GLOBAL::DIRECTORY_SLASH)."\x53\x79\x73\x74\x65\x6d\x33\x32"));}elsif ((defined 
($ENV{"\x48\x4f\x4d\x45\x44\x52\x49\x56\x45"})and (length ($ENV{
"\x48\x4f\x4d\x45\x44\x52\x49\x56\x45"})>(0x0c8d+ 4218-0x1d07)))){($systemPath=(
((($ENV{"\x48\x4f\x4d\x45\x44\x52\x49\x56\x45"}.$GLOBAL::DIRECTORY_SLASH).
"\x57\x69\x6e\x64\x6f\x77\x73").$GLOBAL::DIRECTORY_SLASH).
"\x53\x79\x73\x74\x65\x6d\x33\x32"));}else{Logger::debug (
"\x67\x65\x74\x57\x69\x6e\x64\x6f\x77\x73\x53\x79\x73\x74\x65\x6d\x50\x61\x74\x68\x28\x29\x3a\x20\x75\x6e\x61\x62\x6c\x65\x20\x74\x6f\x20\x73\x65\x74\x20\x70\x61\x74\x68"
);return ((""));}Logger::debug (((
"\x67\x65\x74\x57\x69\x6e\x64\x6f\x77\x73\x53\x79\x73\x74\x65\x6d\x50\x61\x74\x68\x28\x29\x3a\x20\x73\x65\x74\x20\x70\x61\x74\x68\x20\x74\x6f\x20\x5b"
.$systemPath)."\x5d"));return ($systemPath);}sub 
NXTools::getPortAgentMBaseOnDisplay{package NXTools;no warnings;(my $display=
shift (@_));(my $port=($display+getAgentMirrorPortOffset ()));return ($port);}
sub NXTools::getAgentMirrorPortOffset{package NXTools;no warnings;return (
$GLOBAL::PORT_DISPLAY_MIRROR_DELTA);}sub NXTools::getLang{package NXTools;no 
warnings;(my $envLang=libnxh::NXTransGetEnvironment ("\x4c\x41\x4e\x47"));if ((
$envLang eq (""))){Logger::debug2 (
"\x4c\x41\x4e\x47\x20\x65\x6e\x76\x20\x76\x61\x72\x69\x61\x62\x6c\x65\x20\x69\x73\x20\x65\x6d\x70\x74\x79\x2c\x20\x6c\x65\x74\x27\x73\x20\x74\x72\x79\x20\x2e\x64\x6d\x72\x63\x2e"
);($envLang=getLangFromDmrcFile ());if (($envLang eq (""))){Logger::debug2 (
"\x4c\x41\x4e\x47\x20\x65\x6e\x76\x20\x76\x61\x72\x69\x61\x62\x6c\x65\x20\x69\x73\x20\x65\x6d\x70\x74\x79\x2c\x20\x67\x65\x74\x74\x69\x6e\x67\x20\x6c\x61\x6e\x67\x75\x61\x67\x65\x20\x66\x72\x6f\x6d\x20\x64\x61\x65\x6d\x6f\x6e\x20\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x2e"
);($envLang=getServerDaemonLang ());}}return ($envLang);}sub 
NXTools::getLangFromDmrcFile{package NXTools;no warnings;(my $filename=(
Common::NXPaths::getEffectiveUserHomeDirectory ()."\x2f\x2e\x64\x6d\x72\x63"));(my $DMRC_FILE_HANDLE
=main::nxopen ($filename,$NXBits::O_RDONLY,(0x1f8b+ 1496-0x2563),{"\x41\x4c\x4c"
,"\x73\x69\x6c\x65\x6e\x74"}));(my $errorstring=libnxh::NXGetErrorString ());my (
$line);(my $found=(""));if ((not (defined ($DMRC_FILE_HANDLE)))){Logger::debug (
(((
"\x43\x61\x6e\x6e\x6f\x74\x20\x64\x65\x74\x65\x72\x6d\x69\x6e\x65\x20\x4c\x41\x4e\x47\x20\x62\x61\x73\x65\x64\x20\x6f\x6e\x20\x74\x68\x65\x20\x66\x69\x6c\x65\x3a\x20"
.$filename)."\x3a\x20").$errorstring));return ((""));}else{while (
main::nxreadLine ($DMRC_FILE_HANDLE,(\$line))){chomp ($line);if (($line=~ /^Language=(.*)$/ )
){($found=$1);last;}}main::nxclose ($DMRC_FILE_HANDLE);}return ($found);}sub 
NXTools::getServerDaemonLang{package NXTools;no warnings;return (
$GLOBAL::parameters{"\x65\x6e\x76\x4c\x61\x6e\x67"});}sub NXTools::setWidth{
package NXTools;no warnings;(my $refTable=shift (@_));(my $name=shift (@_));(my $value
=shift (@_));if (($$refTable{$name}<length ($value))){($$refTable{$name}=length 
($value));}}sub NXTools::printWidth{package NXTools;no warnings;(my $refTable=
shift (@_));(my $name=shift (@_));(my $value=shift (@_));(my $width=($$refTable{
$name}+(0x1315+ 4387-0x2437)));(my $message=sprintf ((((("\x25\x2d".$width).
"\x2e").$width)."\x73"),$value));if ((main::nxwrite (main::nxgetSTDOUT (),
$message)==(-(0x179a+ 2206-0x2037)))){return ((-(0x1711+ 3860-0x2624)));}}sub 
NXTools::printMark{package NXTools;no warnings;(my $refTable=shift (@_));(my $name
=shift (@_));(my $value=shift (@_));(my $width=($$refTable{$name}+
(0x08bc+ 5727-0x1f1a)));(my $message=sprintf ((((("\x25\x2d".$width)."\x2e").
$width)."\x73"),("\x2d" x $$refTable{$name})));if ((main::nxwrite (
main::nxgetSTDOUT (),$message)==(-(0x02bd+ 3713-0x113d)))){return ((-
(0x0ea2+ 5560-0x2459)));}}sub NXTools::printTable{package NXTools;no warnings;(my $ref_labels
=shift (@_));(my $ref_values=shift (@_));(my (%table)=());for ((my $i=
(0x0521+ 4059-0x14fc));($i<@$ref_labels);(++$i)){setWidth ((\%table),$i,
@$ref_labels[$i]);}foreach my $value (values (%$ref_values)){for ((my $i=
(0x0312+ 8170-0x22fc));($i<@$ref_labels);(++$i)){(my $name=@$ref_labels[$i]);
setWidth ((\%table),$i,$$value{$name});}}for ((my $i=(0x07bb+ 5695-0x1dfa));($i<
@$ref_labels);(++$i)){printWidth ((\%table),$i,@$ref_labels[$i]);}if ((
main::nxwrite (main::nxgetSTDOUT (),"\x0a")==(-(0x0140+ 184-0x01f7)))){return ((
-(0x128c+ 3343-0x1f9a)));}for ((my $i=(0x0155+ 2846-0x0c73));($i<@$ref_labels);(
++$i)){if (printMark ((\%table),$i)){return ((-(0x0467+ 3033-0x103f)));}}if ((
main::nxwrite (main::nxgetSTDOUT (),"\x0a")==(-(0x0cf6+ 4954-0x204f)))){return (
(-(0x1ceb+ 471-0x1ec1)));}foreach my $key (sort (keys (%$ref_values))){(my $value
=$$ref_values{$key});for ((my $i=(0x0f71+ 737-0x1252));($i<@$ref_labels);(++$i))
{(my $name=@$ref_labels[$i]);if (printWidth ((\%table),$i,$$value{$name})){
return ((-(0x0653+ 7825-0x24e3)));}}if ((main::nxwrite (main::nxgetSTDOUT (),
"\x0a")==(-(0x03a3+ 2533-0x0d87)))){return ((-(0x09b6+ 7479-0x26ec)));}}if ((
main::nxwrite (main::nxgetSTDOUT (),"\x0a")==(-(0x0972+ 6531-0x22f4)))){return (
(-(0x0461+ 7131-0x203b)));}return ((0x06d6+ 2256-0x0fa6));}package NXTools;no 
warnings;"\x3f\x3f\x3f";

==> nomachine-8.0.168-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/NXTools.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXTools::BEGIN{package NXTools;no warnings;require Common::NXPaths;do{
"\x43\x6f\x6d\x6d\x6f\x6e\x3a\x3a\x4e\x58\x50\x61\x74\x68\x73"->import};}sub 
NXTools::BEGIN{package NXTools;no warnings;require Common::NXPaths;do{
"\x43\x6f\x6d\x6d\x6f\x6e\x3a\x3a\x4e\x58\x50\x61\x74\x68\x73"->import};}sub 
NXTools::getWindowsSystemPath{package NXTools;no warnings;(my $systemPath=(""));
if ((defined ($ENV{
"\x53\x79\x73\x74\x65\x6d\x44\x69\x72\x65\x63\x74\x6f\x72\x79"})and (length (
$ENV{"\x53\x79\x73\x74\x65\x6d\x44\x69\x72\x65\x63\x74\x6f\x72\x79"})>
(0x0a87+ 5842-0x2159)))){($systemPath=$ENV{
"\x53\x79\x73\x74\x65\x6d\x44\x69\x72\x65\x63\x74\x6f\x72\x79"});}elsif ((
defined ($ENV{"\x57\x69\x6e\x44\x69\x72"})and (length ($ENV{
"\x57\x69\x6e\x44\x69\x72"})>(0x1810+ 1486-0x1dde)))){($systemPath=(($ENV{
"\x57\x69\x6e\x44\x69\x72"}.$GLOBAL::DIRECTORY_SLASH).
"\x53\x79\x73\x74\x65\x6d\x33\x32"));}elsif ((defined ($ENV{
"\x53\x79\x73\x74\x65\x6d\x52\x6f\x6f\x74"})and (length ($ENV{
"\x53\x79\x73\x74\x65\x6d\x52\x6f\x6f\x74"})>(0x0f68+ 1532-0x1564)))){(
$systemPath=(($ENV{"\x53\x79\x73\x74\x65\x6d\x52\x6f\x6f\x74"}.
$GLOBAL::DIRECTORY_SLASH)."\x53\x79\x73\x74\x65\x6d\x33\x32"));}elsif ((defined 
($ENV{"\x53\x79\x73\x74\x65\x6d\x44\x72\x69\x76\x65"})and (length ($ENV{
"\x53\x79\x73\x74\x65\x6d\x44\x72\x69\x76\x65"})>(0x1bd2+ 237-0x1cbf)))){(
$systemPath=(((($ENV{"\x53\x79\x73\x74\x65\x6d\x44\x72\x69\x76\x65"}.
$GLOBAL::DIRECTORY_SLASH)."\x57\x69\x6e\x64\x6f\x77\x73").
$GLOBAL::DIRECTORY_SLASH)."\x53\x79\x73\x74\x65\x6d\x33\x32"));}elsif ((defined 
($ENV{"\x48\x4f\x4d\x45\x44\x52\x49\x56\x45"})and (length ($ENV{
"\x48\x4f\x4d\x45\x44\x52\x49\x56\x45"})>(0x06ef+ 809-0x0a18)))){($systemPath=((
(($ENV{"\x48\x4f\x4d\x45\x44\x52\x49\x56\x45"}.$GLOBAL::DIRECTORY_SLASH).
"\x57\x69\x6e\x64\x6f\x77\x73").$GLOBAL::DIRECTORY_SLASH).
"\x53\x79\x73\x74\x65\x6d\x33\x32"));}else{Logger::debug (
"\x67\x65\x74\x57\x69\x6e\x64\x6f\x77\x73\x53\x79\x73\x74\x65\x6d\x50\x61\x74\x68\x28\x29\x3a\x20\x75\x6e\x61\x62\x6c\x65\x20\x74\x6f\x20\x73\x65\x74\x20\x70\x61\x74\x68"
);return ((""));}Logger::debug (((
"\x67\x65\x74\x57\x69\x6e\x64\x6f\x77\x73\x53\x79\x73\x74\x65\x6d\x50\x61\x74\x68\x28\x29\x3a\x20\x73\x65\x74\x20\x70\x61\x74\x68\x20\x74\x6f\x20\x5b"
.$systemPath)."\x5d"));return ($systemPath);}sub 
NXTools::getPortAgentMBaseOnDisplay{package NXTools;no warnings;(my $display=
shift (@_));(my $port=($display+getAgentMirrorPortOffset ()));return ($port);}
sub NXTools::getAgentMirrorPortOffset{package NXTools;no warnings;return (
$GLOBAL::PORT_DISPLAY_MIRROR_DELTA);}sub NXTools::getLang{package NXTools;no 
warnings;(my $envLang=libnxh::NXTransGetEnvironment ("\x4c\x41\x4e\x47"));if ((
$envLang eq (""))){Logger::debug2 (
"\x4c\x41\x4e\x47\x20\x65\x6e\x76\x20\x76\x61\x72\x69\x61\x62\x6c\x65\x20\x69\x73\x20\x65\x6d\x70\x74\x79\x2c\x20\x6c\x65\x74\x27\x73\x20\x74\x72\x79\x20\x2e\x64\x6d\x72\x63\x2e"
);($envLang=getLangFromDmrcFile ());if (($envLang eq (""))){Logger::debug2 (
"\x4c\x41\x4e\x47\x20\x65\x6e\x76\x20\x76\x61\x72\x69\x61\x62\x6c\x65\x20\x69\x73\x20\x65\x6d\x70\x74\x79\x2c\x20\x67\x65\x74\x74\x69\x6e\x67\x20\x6c\x61\x6e\x67\x75\x61\x67\x65\x20\x66\x72\x6f\x6d\x20\x64\x61\x65\x6d\x6f\x6e\x20\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x2e"
);($envLang=getServerDaemonLang ());}}return ($envLang);}sub 
NXTools::getLangFromDmrcFile{package NXTools;no warnings;(my $filename=(
Common::NXPaths::getEffectiveUserHomeDirectory ()."\x2f\x2e\x64\x6d\x72\x63"));(my $DMRC_FILE_HANDLE
=main::nxopen ($filename,$NXBits::O_RDONLY,(0x01ba+ 7668-0x1fae),{"\x41\x4c\x4c"
,"\x73\x69\x6c\x65\x6e\x74"}));(my $errorstring=libnxh::NXGetErrorString ());my (
$line);(my $found=(""));if ((not (defined ($DMRC_FILE_HANDLE)))){Logger::debug (
(((
"\x43\x61\x6e\x6e\x6f\x74\x20\x64\x65\x74\x65\x72\x6d\x69\x6e\x65\x20\x4c\x41\x4e\x47\x20\x62\x61\x73\x65\x64\x20\x6f\x6e\x20\x74\x68\x65\x20\x66\x69\x6c\x65\x3a\x20"
.$filename)."\x3a\x20").$errorstring));return ((""));}else{while (
main::nxreadLine ($DMRC_FILE_HANDLE,(\$line))){chomp ($line);if (($line=~ /^Language=(.*)$/ )
){($found=$1);last;}}main::nxclose ($DMRC_FILE_HANDLE);}return ($found);}sub 
NXTools::getServerDaemonLang{package NXTools;no warnings;return (
$GLOBAL::parameters{"\x65\x6e\x76\x4c\x61\x6e\x67"});}sub NXTools::setWidth{
package NXTools;no warnings;(my $refTable=shift (@_));(my $name=shift (@_));(my $value
=shift (@_));if (($$refTable{$name}<length ($value))){($$refTable{$name}=length 
($value));}}sub NXTools::printWidth{package NXTools;no warnings;(my $refTable=
shift (@_));(my $name=shift (@_));(my $value=shift (@_));(my $width=($$refTable{
$name}+(0x0d6a+ 2110-0x15a7)));(my $message=sprintf ((((("\x25\x2d".$width).
"\x2e").$width)."\x73"),$value));if ((main::nxwrite (main::nxgetSTDOUT (),
$message)==(-(0x005a+ 5004-0x13e5)))){return ((-(0x0a2c+ 1276-0x0f27)));}}sub 
NXTools::printMark{package NXTools;no warnings;(my $refTable=shift (@_));(my $name
=shift (@_));(my $value=shift (@_));(my $width=($$refTable{$name}+
(0x1764+ 1452-0x1d0f)));(my $message=sprintf ((((("\x25\x2d".$width)."\x2e").
$width)."\x73"),("\x2d" x $$refTable{$name})));if ((main::nxwrite (
main::nxgetSTDOUT (),$message)==(-(0x0f5f+ 3921-0x1eaf)))){return ((-
(0x019b+ 2633-0x0be3)));}}sub NXTools::printTable{package NXTools;no warnings;(my $ref_labels
=shift (@_));(my $ref_values=shift (@_));(my (%table)=());for ((my $i=
(0x0335+ 292-0x0459));($i<@$ref_labels);(++$i)){setWidth ((\%table),$i,
@$ref_labels[$i]);}foreach my $value (values (%$ref_values)){for ((my $i=
(0x0737+ 5058-0x1af9));($i<@$ref_labels);(++$i)){(my $name=@$ref_labels[$i]);
setWidth ((\%table),$i,$$value{$name});}}for ((my $i=(0x18c4+ 1417-0x1e4d));($i<
@$ref_labels);(++$i)){printWidth ((\%table),$i,@$ref_labels[$i]);}if ((
main::nxwrite (main::nxgetSTDOUT (),"\x0a")==(-(0x10b6+ 831-0x13f4)))){return ((
-(0x07b7+ 5279-0x1c55)));}for ((my $i=(0x07cf+ 141-0x085c));($i<@$ref_labels);(
++$i)){if (printMark ((\%table),$i)){return ((-(0x15a5+ 3526-0x236a)));}}if ((
main::nxwrite (main::nxgetSTDOUT (),"\x0a")==(-(0x0703+ 5392-0x1c12)))){return (
(-(0x0abb+ 6836-0x256e)));}foreach my $key (sort (keys (%$ref_values))){(my $value
=$$ref_values{$key});for ((my $i=(0x1877+ 945-0x1c28));($i<@$ref_labels);(++$i))
{(my $name=@$ref_labels[$i]);if (printWidth ((\%table),$i,$$value{$name})){
return ((-(0x022f+ 947-0x05e1)));}}if ((main::nxwrite (main::nxgetSTDOUT (),
"\x0a")==(-(0x03ab+ 2115-0x0bed)))){return ((-(0x06ea+ 5129-0x1af2)));}}if ((
main::nxwrite (main::nxgetSTDOUT (),"\x0a")==(-(0x0702+ 6228-0x1f55)))){return (
(-(0x2215+ 1215-0x26d3)));}return ((0x075a+ 7964-0x2676));}package NXTools;no 
warnings;"\x3f\x3f\x3f";
